@@ -1,8 +1,8 @@
 // -*- C++ -*-
-// $Id: 51_gcc_str.c 5416 2005-08-25 12:47:15Z wsnyder $
+// $Id: 51_gcc_str.c 12022 2006-01-16 21:55:21Z wsnyder $
 // DESCRIPTION: C file compiled as part of test suite
 //
-// Copyright 2005-2005 by Wilson Snyder.  This program is free software;
+// Copyright 2005-2006 by Wilson Snyder.  This program is free software;
 // you can redistribute it and/or modify it under the terms of either the GNU
 // General Public License or the Perl Artistic License.
 
@@ -15,8 +15,8 @@
 // Just enough so we know it compiles and run!
 int main() {
     ExClassOne clOne;
-    ExClassOne_fieldsZero(&clOne);
-    ExClassOne_cmd_set(&clOne, ExEnum_ONE);
-    ExClassOne_address_set(&clOne, 0x1234);
+    exClassOne_fieldsZero (&clOne);
+    exClassOne_cmd_set    (&clOne, ExEnum_ONE);
+    exClassOne_address_set(&clOne, 0x1234);
     return (0);
 }
